<?php

declare(strict_types=1);

namespace Drupal\simple_sitemap_exclude\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\simple_sitemap\Form\SimpleSitemapFormBase;

/**
 * Configure Simple XML sitemap exclude pattern settings for this site.
 */
final class SettingsForm extends SimpleSitemapFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'simple_sitemap_exclude_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['simple_sitemap_exclude.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['patterns'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Patterns'),
      '#default_value' => empty($this->config('simple_sitemap_exclude.settings')->get('patterns')) ? [] : implode("\n", $this->config('simple_sitemap_exclude.settings')->get('patterns')),
      '#description' => $this->t('Pattern examples: <ul><li><code>^\/home$</code> for <code>/nome</code></li><li><code>^\/node\/.*</code> for <code>/node/*</code></li></ul>Use <a href="https://www.php.net/manual/en/function.preg-match.php" target="_blank">preg_match() function</a> patterns.'),
    ];

    $form = $this->formHelper->regenerateNowForm($form);

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    // Remove empty values and trim values.
    $values = explode("\n", $form_state->getValue('patterns'));
    $values = array_map('trim', $values);
    $values = array_values(array_filter($values, fn($value) => $value && $value !== ''));

    $this->config('simple_sitemap_exclude.settings')
      ->set('patterns', $values)
      ->save();
    parent::submitForm($form, $form_state);
  }

}
